OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Αδυναμία εγγραφής στον κατάλογο \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Αυτό μπορεί συνήθως να διορθωθεί παρέχοντας δικαιώματα εγγραφής για το φάκελο config στον διακομιστή ιστού.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ή εάν επιθυμείτε να διατηρήσετε το config.php σε κατάσταση ανάγνωσης μόνο, ορίστε την επιλογή \"config_is_read_only\" σε true.",
    "See %s" : "Δείτε %s",
    "Sample configuration detected" : "Ανιχνεύθηκε παράδειγμα εγκατάστασης",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Έχει ανιχνευθεί ότι το δείγμα εγκατάστασης έχει αντιγραφεί. Αυτό μπορεί να σπάσει την εγκατάστασή σας και δεν υποστηρίζεται. Παρακαλούμε διαβάστε την τεκμηρίωση πριν εκτελέσετε αλλαγές στο config.php",
    "The page could not be found on the server." : "Αυτή η σελίδα δε βρέθηκε στον διακομιστή.",
    "%s email verification" : "%s επαλήθευση email",
    "Email verification" : "Επαλήθευση email",
    "Click the following button to confirm your email." : "Κάντε κλικ στο παρακάτω κουμπί για να επιβεβαιώσετε το email σας.",
    "Click the following link to confirm your email." : "Κάντε κλικ στον παρακάτω σύνδεσμο για να επιβεβαιώσετε το email σας.",
    "Confirm your email" : "Επιβεβαιώστε το email σας",
    "Other activities" : "Άλλες δραστηριότητες",
    "%1$s and %2$s" : "%1$s και %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s και %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s και %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s και %5$s",
    "Education Edition" : "Εκπαιδευτική Έκδοση",
    "Enterprise bundle" : "Πακέτο επιχειρήσεων",
    "Groupware bundle" : "Πακέτο Groupware",
    "Hub bundle" : "Hub bundle",
    "Social sharing bundle" : "Πακέτο κοινωνικού διαμοιρασμού",
    "PHP %s or higher is required." : "PHP %s ή νεώτερη απαιτείται.",
    "PHP with a version lower than %s is required." : "Απαιτείται PHP παλαιότερη από την έκδοση %s.",
    "%sbit or higher PHP required." : "%sbit απαιτείται νεώτερη έκδοση PHP.",
    "The following architectures are supported: %s" : "Υποστηρίζονται οι ακόλουθες αρχιτεκτονικές: %s",
    "The following databases are supported: %s" : " Υποστηρίζονται οι ακόλουθες βάσεις δεδομένων: %s",
    "The command line tool %s could not be found" : "Το εργαλείο γραμμής εντολών %s δεν μπορεί να βρεθεί",
    "The library %s is not available." : "Το %s της βιβλιοθήκης δεν είναι διαθέσιμο.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Απαιτείται βιβλιοθήκη %1$s νεότερη από την έκδοση %2$s - διαθέσιμη έκδοση  %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Απαιτείται βιβλιοθήκη %1$s παλαιότερη από την έκδοση %2$s  - διαθέσιμη έκδοση  %3$s.",
    "The following platforms are supported: %s" : "Υποστηρίζονται οι ακόλουθες πλατφόρμες: %s",
    "Server version %s or higher is required." : "Απαιτείται έκδοση διακομιστή %s ή νεότερη.",
    "Server version %s or lower is required." : "Απαιτείται έκδοση διακομιστή %s ή παλαιότερη.",
    "Wiping of device %s has started" : "Η εκκαθάριση συσκευής %s ξεκίνησε",
    "Wiping of device »%s« has started" : "Η εκκαθάριση συσκευής »%s« ξεκίνησε",
    "»%s« started remote wipe" : "»%s« ξεκίνησε η απομακρυσμένη εκκαθάριση",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Η συσκευή ή εφαρμογή »%s« ξεκίνησε απομακρυσμένη εκκαθάριση. Θα λάβετε ένα ηλ.μήνυμα μόλις ολοκληρωθεί",
    "Wiping of device %s has finished" : "Η εκκαθάριση συσκευής %s ολοκληρώθηκε",
    "Wiping of device »%s« has finished" : "Η εκκαθάριση συσκευής »%s« ολοκληρώθηκε",
    "»%s« finished remote wipe" : "»%s« ολοκληρώθηκε η απομακρυσμένη εκκαθάριση",
    "Device or application »%s« has finished the remote wipe process." : "Η συσκευή ή εφαρμογή »%s« ολοκλήρωσε την απομακρυσμένη εκκαθάριση.",
    "Remote wipe started" : "Η απομακρυσμένη εκκαθάριση ξεκίνησε",
    "A remote wipe was started on device %s" : "Η απομακρυσμένη εκκαθάριση ξεκίνησε στην συσκευή %s",
    "Remote wipe finished" : "Η απομακρυσμένη εκκαθάριση ολοκληρώθηκε",
    "The remote wipe on %s has finished" : "Η απομακρυσμένη εκκαθάριση στο %s ολοκληρώθηκε",
    "Authentication" : "Πιστοποίηση",
    "Unknown filetype" : "Άγνωστος τύπος αρχείου",
    "Invalid image" : "Μη έγκυρη εικόνα",
    "Avatar image is not square" : "Η εικόνα του άβαταρ δεν είναι τετράγωνη",
    "Files" : "Αρχεία",
    "View profile" : "Προβολή προφίλ",
    "Local time: %s" : "Τοπική ώρα: %s",
    "today" : "σήμερα",
    "tomorrow" : "αύριο",
    "yesterday" : "χθες",
    "_in %n day_::_in %n days_" : ["σε %n ημέρα","σε %n ημέρες"],
    "_%n day ago_::_%n days ago_" : ["%n ημέρα πριν","%n ημέρες πριν"],
    "next month" : "επόμενος μήνας",
    "last month" : "τελευταίο μήνα",
    "_in %n month_::_in %n months_" : ["σε %n μήνα","σε %n μήνες"],
    "_%n month ago_::_%n months ago_" : ["πριν %n μήνα","πριν %n μήνες"],
    "next year" : "επόμενος χρόνος",
    "last year" : "τελευταίο χρόνο",
    "_in %n year_::_in %n years_" : ["σε %n χρόνο","σε %n χρόνια"],
    "_%n year ago_::_%n years ago_" : ["%n χρόνο πριν","%n χρόνια πριν"],
    "_in %n hour_::_in %n hours_" : ["σε %n ώρα","σε %n ώρες"],
    "_%n hour ago_::_%n hours ago_" : ["%n ώρα πριν","%n ώρες πριν"],
    "_in %n minute_::_in %n minutes_" : ["σε %n λεπτό","σε %n λεπτά"],
    "_%n minute ago_::_%n minutes ago_" : ["%nλεπτό πριν","%nλεπτά πριν"],
    "in a few seconds" : "σε λίγα δευτερόλεπτα",
    "seconds ago" : "δευτερόλεπτα πριν",
    "Empty file" : "Κενό αρχείο",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Το άρθρωμα με ID: %sδεν υπάρχει. Παρακαλούμε ενεργοποιήστε το στις ρυθμίσεις των εφαρμογών σας ή επικοινωνήστε με τον διαχειριστή.",
    "File already exists" : "Το αρχείο υπάρχει ήδη",
    "Invalid path" : "Μη έγκυρη διαδρομή",
    "Failed to create file from template" : "Η δημιουργία αρχείου από το πρότυπο απέτυχε",
    "Templates" : "Πρότυπα",
    "File name is a reserved word" : "Το όνομα αρχείου είναι λέξη που έχει δεσμευτεί",
    "File name contains at least one invalid character" : "Το όνομα αρχείου περιέχει έναν τουλάχιστον μη έγκυρο χαρακτήρα",
    "File name is too long" : "Το όνομα αρχείου είναι πολύ μεγάλο",
    "Dot files are not allowed" : "Δεν επιτρέπονται αρχεία που ξεκινούν με τελεία",
    "Empty filename is not allowed" : "Δεν επιτρέπεται άδειο όνομα αρχείου",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Η εφαρμογή \"%s\" δεν μπορεί να εγκατασταθεί διότι δεν είναι δυνατή η ανάγνωση του αρχείου appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Η εφαρμογή \"%s\" δεν μπορεί να εγκατασταθεί διότι δεν είναι συμβατή με την έκδοση του διακομιστή.",
    "__language_name__" : "Ελληνικά",
    "This is an automatically sent email, please do not reply." : "Αυτό είναι ένα μήνυμα ηλεκτρονικού ταχυδρομείου που στάλθηκε αυτόματα, παρακαλούμε μην απαντήσετε.",
    "Help" : "Βοήθεια",
    "Appearance and accessibility" : "Εμφάνιση και προσβασιμότητα",
    "Apps" : "Εφαρμογές",
    "Personal settings" : "Προσωπικές ρυθμίσεις",
    "Administration settings" : "Ρυθμίσεις διαχείρισης",
    "Settings" : "Ρυθμίσεις",
    "Log out" : "Έξοδος",
    "Users" : "Χρήστες",
    "Email" : "Email",
    "Mail %s" : "Mail στο %s",
    "Phone" : "Τηλέφωνο",
    "Call %s" : "Καλέστε το %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Προβολή %s στο Twitter",
    "Website" : "Ιστοσελίδα",
    "Visit %s" : "Επισκεφτείτε το %s",
    "Address" : "Διεύθυνση",
    "Profile picture" : "Εικόνα προφίλ",
    "About" : "Σχετικά με",
    "Headline" : "Τίτλος",
    "Organisation" : "Οργανισμός",
    "Role" : "Ρόλος/Θέση",
    "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
    "You need to enter details of an existing account." : "Χρειάζεται να εισάγετε λεπτομέρειες από υπάρχοντα λογαριασμό.",
    "Oracle connection could not be established" : "Αδυναμία σύνδεσης Oracle",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Το Mac OS X δεν υποστηρίζεται και το %s δεν θα λειτουργήσει σωστά σε αυτή την πλατφόρμα. Χρησιμοποιείτε με δική σας ευθύνη!",
    "For the best results, please consider using a GNU/Linux server instead." : "Για καλύτερα αποτελέσματα, παρακαλούμε εξετάστε την μετατροπή σε έναν διακομιστή GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Φαίνεται ότι η εγκατάσταση %s εκτελείται σε περιβάλλον 32-bit PHP και η επιλογή open_basedir έχει ρυθμιστεί στο αρχείο php.ini. Αυτό θα οδηγήσει σε προβλήματα με αρχεία πάνω από 4 GB και δεν συνίσταται.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Παρακαλούμε αφαιρέστε την ρύθμιση open_basedir μέσα στο αρχείο php.ini ή αλλάξτε σε 64-bit PHP.",
    "Set an admin password." : "Εισάγετε συνθηματικό διαχειριστή.",
    "Cannot create or write into the data directory %s" : "Δεν είναι δυνατή η δημιουργία ή εγγραφή στον κατάλογο δεδομένων %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Το σύστημα διαμοιρασμού %s πρέπει να υλοποιεί την διεπαφή OCP\\Share_Backend",
    "Sharing backend %s not found" : "Το σύστημα διαμοιρασμού %s δεν βρέθηκε",
    "Sharing backend for %s not found" : "Το σύστημα διαμοιρασμού για το %s δεν βρέθηκε",
    "%1$s shared »%2$s« with you and wants to add:" : "Ο %1$s διαμοιράστηκε το »%2$s« με εσάς και θέλει να προσθέσει:",
    "%1$s shared »%2$s« with you and wants to add" : "Ο %1$s διαμοιράστηκε το »%2$s« με εσάς και θέλει να προσθέσει",
    "»%s« added a note to a file shared with you" : "Ο »%s« πρόσθεσε μια σημείωση στο κοινόχρηστο αρχείο",
    "Open »%s«" : "Άνοιγμα »%s«",
    "%1$s via %2$s" : "%1$s μέσω %2$s",
    "You are not allowed to share %s" : "Δεν σας επιτρέπεται ο διαμοιρασμός %s",
    "Cannot increase permissions of %s" : "Αδυναμία αύξησης των δικαιωμάτων του/της %s",
    "Files cannot be shared with delete permissions" : "Δεν είναι δυνατή η κοινή χρήση αρχείων με δικαιώματα διαγραφής",
    "Files cannot be shared with create permissions" : "Δεν είναι δυνατή η κοινή χρήση αρχείων με δικαιώματα δημιουργίας",
    "Expiration date is in the past" : "Η ημερομηνία λήξης είναι στο παρελθόν",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Δεν είναι δυνατός ο ορισμός ημερομηνίας λήξης για περισσότερο από %n ημέρα στο μέλλον","Δεν είναι δυνατός ο ορισμός ημερομηνίας λήξης για περισσότερες από %n ημέρες στο μέλλον"],
    "Sharing is only allowed with group members" : "Η κοινή χρήση επιτρέπεται μόνο με μέλη της ομάδας",
    "%1$s shared »%2$s« with you" : "Ο/η %1$s διαμοιράστηκε το »%2$s« με εσάς.",
    "%1$s shared »%2$s« with you." : "Ο/η %1$s διαμοιράστηκε »%2$s« με εσάς.",
    "Click the button below to open it." : "Κάντε κλικ στο παρακάτω κουμπί για να το ανοίξετε.",
    "The requested share does not exist anymore" : "Το διαμοιρασμένο που ζητήθηκε δεν υπάρχει πλέον",
    "Could not find category \"%s\"" : "Αδυναμία εύρεσης κατηγορίας \"%s\"",
    "Sunday" : "Κυριακή",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Sun." : "Κυρ.",
    "Mon." : "Δευ.",
    "Tue." : "Τρί.",
    "Wed." : "Τετ.",
    "Thu." : "Πέμ.",
    "Fri." : "Παρ.",
    "Sat." : "Σαβ.",
    "Su" : "Κυ",
    "Mo" : "Δε",
    "Tu" : "Τρ",
    "We" : "Τε",
    "Th" : "Πε",
    "Fr" : "Πα",
    "Sa" : "Σα",
    "January" : "Ιανουάριος",
    "February" : "Φεβρουάριος",
    "March" : "Μάρτιος",
    "April" : "Απρίλιος",
    "May" : "Μάϊος",
    "June" : "Ιούνιος",
    "July" : "Ιούλιος",
    "August" : "Αύγουστος",
    "September" : "Σεπτέμβριος",
    "October" : "Οκτώβριος",
    "November" : "Νοέμβριος",
    "December" : "Δεκέμβριος",
    "Jan." : "Ιαν.",
    "Feb." : "Φεβ.",
    "Mar." : "Μαρ.",
    "Apr." : "Απρ.",
    "May." : "Μαι.",
    "Jun." : "Ιουν.",
    "Jul." : "Ιουλ.",
    "Aug." : "Αυγ.",
    "Sep." : "Σεπ.",
    "Oct." : "Οκτ.",
    "Nov." : "Νοε.",
    "Dec." : "Δεκ.",
    "A valid password must be provided" : "Πρέπει να δοθεί έγκυρο συνθηματικό",
    "Login canceled by app" : "Η είσοδος ακυρώθηκε από την εφαρμογή",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Η εφαρμογή \"%1$s\" δεν μπορεί να εγκατασταθεί επειδή δεν πληρούνται τα προαπαιτούμενα: %2$s",
    "a safe home for all your data" : "ένα ασφαλές μέρος για όλα τα δεδομένα σας",
    "File is currently busy, please try again later" : "Το αρχείο χρησιμοποιείται αυτή τη στιγμή, παρακαλούμε προσπαθήστε αργότερα",
    "Cannot download file" : "Δεν είναι δυνατή η λήψη του αρχείου",
    "Application is not enabled" : "Δεν ενεργοποιήθηκε η εφαρμογή",
    "Authentication error" : "Σφάλμα πιστοποίησης",
    "Token expired. Please reload page." : "Το αναγνωριστικό έληξε. Παρακαλούμε φορτώστε ξανά την σελίδα.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Δεν βρέθηκαν εγκατεστημένοι οδηγοί βάσεων δεδομένων (sqlite, mysql, or postgresql).",
    "Cannot write into \"config\" directory." : "Δεν είναι δυνατή η εγγραφή στον κατάλογο \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού δικαιώματα εγγραφής στον κατάλογο config. Δείτε το%s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ή εάν επιθυμείτε να διατηρήσετε το config.php σε κατάσταση ανάγνωσης μόνο, καθορίστε το από τις επιλογές του σε true του \"config_is_read_only\". Δείτε %s",
    "Cannot write into \"apps\" directory." : "Δεν είναι δυνατή η εγγραφή στον κατάλογο \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού πρόσβαση εγγραφής στον κατάλογο apps ή απενεργοποιώντας το App Store στο αρχείο διαμόρφωσης config.",
    "Cannot create \"data\" directory." : "Δεν είναι δυνατή η δημιουργία καταλόγου \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Αυτό μπορεί συνήθως να διορθωθεί δίνοντας στον διακομιστή ιστού δικαιώματα εγγραφής στον ριζικό κατάλογο. Δείτε το%s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Τα δικαιώματα μπορούν συνήθως να διορθωθούν δίνοντας στον διακομιστή ιστού πρόσβαση εγγραφής στον ριζικό κατάλογο. Δείτε το%s.",
    "Your data directory is not writable." : "Ο κατάλογος δεδομένων σας δεν είναι εγγράψιμος.",
    "Setting locale to %s failed." : "Η ρύθμιση τοπικών ρυθμίσεων σε %s απέτυχε.",
    "Please install one of these locales on your system and restart your web server." : "Παρακαλούμε να εγκαταστήσετε μία από αυτές τις τοπικές ρυθμίσεις στο σύστημά σας και να επανεκκινήστε τον διακομιστή ιστού σας.",
    "PHP module %s not installed." : "Η μονάδα %s PHP δεν είναι εγκατεστημένη. ",
    "Please ask your server administrator to install the module." : "Παρακαλούμε ζητήστε από το διαχειριστή του διακομιστή σας να εγκαταστήσει τη μονάδα.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Η ρύθμιση \"%s\"της PHP δεν είναι ορισμένη σε \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Προσαρμόζοντας αυτήν τη ρύθμιση στο php.ini το Nextcloud θα εκτελεστεί ξανά",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Το <code>mbstring.func_overload</code> έχει ορισθεί σε <code>%s</code> αντί για την αναμενόμενη τιμή <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Για να διορθώσετε αυτό το πρόβλημα ορίστε το <code>mbstring.func_overload</code> σε <code>0</code> στο αρχείο php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Η PHP φαίνεται να είναι ρυθμισμένη ώστε να αφαιρεί inline doc blocks. Αυτό θα καταστήσει πολλές βασικές εφαρμογές μη διαθέσιμες.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Αυτό πιθανόν προκλήθηκε από προσωρινή μνήμη (cache)/επιταχυντή όπως τη Zend OPcache ή τον eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Κάποια αρθρώματα της PHP έχουν εγκατασταθεί, αλλά είναι ακόμα καταγεγραμμένες ως εκλιπόντα;",
    "Please ask your server administrator to restart the web server." : "Παρακαλούμε ζητήστε από το διαχειριστή του διακομιστή σας να επανεκκινήσει το διακομιστή δικτύου σας.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Παρακαλούμε ζητήστε από το διαχειριστή του διακομιστή σας να ελέγξει τη διαμόρφωση του Nextcloud.",
    "Your data directory must be an absolute path." : "Ο κατάλογος δεδομένων σας πρέπει να είναι μια απόλυτη διαδρομή.",
    "Check the value of \"datadirectory\" in your configuration." : "Ελέγξτε την τιμή του \"datadirectory\" στις ρυθμίσεις σας.",
    "Your data directory is invalid." : "Ο κατάλογος δεδομένων σας δεν είναι έγκυρος.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Εξασφαλίστε ότι υπάρχει ένα αρχείο με όνομα \".ocdata\" στον βασικό κατάλογο του καταλόγου δεδομένων.",
    "Action \"%s\" not supported or implemented." : "Η ενέργεια \"%s\" δεν υποστηρίζεται ή δεν μπορεί να υλοποιηθεί.",
    "Authentication failed, wrong token or provider ID given" : "Ο έλεγχος ταυτότητας απέτυχε, δόθηκε λανθασμένο αναγνωριστικό ή αναγνωριστικό παρόχου",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Απουσιάζουν παράμετροι για την ολοκλήρωση του αιτήματος.  Ελλιπείς παράμετροι: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Το αναγνωριστικό \"%1$s\" χρησιμοποιείται ήδη από τον  ομόσπονδο πάροχο \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud Federation Provider with ID: \"%s\" δεν υπάρχει.",
    "Could not obtain lock type %d on \"%s\"." : "Αδυναμία ανάκτησης τύπου κλειδώματος %d στο \"%s\".",
    "Storage unauthorized. %s" : "Αποθηκευτικός χώρος χωρίς εξουσιοδότηση. %s",
    "Storage incomplete configuration. %s" : "Ελλιπής διαμόρφωση αποθηκευτικού χώρου. %s",
    "Storage connection error. %s" : "Σφάλμα σύνδεσης με αποθηκευτικό χώρο. %s",
    "Storage is temporarily not available" : "Ο χώρος αποθήκευσης δεν είναι διαθέσιμος προσωρινά",
    "Storage connection timeout. %s" : "Λήξη χρονικού ορίου σύνδεσης με αποθηκευτικό χώρο.%s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Τα αρχεία της εφαρμογής %1$s δεν αντικαταστάθηκαν σωστά. Βεβαιωθείτε ότι πρόκειται για συμβατή έκδοση με το διακομιστή.",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Ο συνδεδεμένος χρήστης πρέπει να είναι διαχειριστής, υποδιαχειριστής ή να έχει ειδικό δικαίωμα πρόσβασης σε αυτήν τη ρύθμιση",
    "Logged in user must be an admin or sub admin" : "Ο συνδεδεμένος χρήστης πρέπει να είναι admin ή subadmin",
    "Logged in user must be an admin" : "Ο συνδεδεμένος χρήστης πρέπει να είναι διαχειριστής",
    "Full name" : "Πλήρες όνομα",
    "Unknown user" : "Άγνωστος χρήστης",
    "MySQL username and/or password not valid" : "Το όνομα χρήστη και/'η ο κωδικός πρόσβασης MySQL δεν είναι σωστά",
    "Oracle username and/or password not valid" : "Μη έγκυρος χρήστης και/ή συνθηματικό της Oracle",
    "PostgreSQL username and/or password not valid" : "Μη έγκυρος χρήστης και/ή συνθηματικό της PostgreSQL",
    "Set an admin username." : "Εισάγετε όνομα χρήστη διαχειριστή.",
    "Sharing %s failed, because this item is already shared with user %s" : "Η κοινή χρήση του %s απέτυχε, επειδή αυτό το στοιχείο είναι ήδη κοινόχρηστο με τον χρήστη %s",
    "The username is already being used" : "Το όνομα χρήστη είναι κατειλημμένο",
    "Could not create user" : "Αδυναμία δημιουργίας χρήστη",
    "A valid username must be provided" : "Πρέπει να δοθεί έγκυρο όνομα χρήστη",
    "Username contains whitespace at the beginning or at the end" : "Το όνομα χρήστη περιέχει κενό διάστημα στην αρχή ή στο τέλος",
    "Username must not consist of dots only" : "Το όνομα χρήστη δεν πρέπει να περιέχει μόνο τελείες",
    "Username is invalid because files already exist for this user" : "Το όνομα χρήστη δεν είναι έγκυρο, επειδή υπάρχουν ήδη αρχεία για αυτόν τον χρήστη",
    "User disabled" : "Ο χρήστης απενεργοποιήθηκε",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Απαιτείται τουλάχιστον το libxml2 2.7.0. Αυτή τη στιγμή είναι εγκατεστημένο το %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Για να διορθώσετε το σφάλμα ενημερώστε την έκδοση του libxml2 και επανεκκινήστε τον διακομιστή.",
    "PostgreSQL >= 9 required." : "Απαιτείται PostgreSQL >= 9.",
    "Please upgrade your database version." : "Παρακαλούμε αναβαθμίστε την έκδοση της βάσης δεδομένων σας.",
    "Your data directory is readable by other users." : "Ο κατάλογος δεδομένων σας είναι αναγνώσιμος από άλλους χρήστες.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Παρακαλούμε αλλάξτε τις ρυθμίσεις σε 0770 έτσι ώστε ο κατάλογος να μην μπορεί να προβάλλεται από άλλους χρήστες."
},
"nplurals=2; plural=(n != 1);");
